@@ -26,21 +26,26 @@ has 'statistics' => (
     lazy_build => 1,
 );
 
-sub create_cache_record
+#
+# create REQ
+#
+sub create
 {
-    my ($self,$name,$normaliser,$coderef,$args,$return_type) = @_;
-###l4p     get_logger()->debug( "create_cache_record" );
+    my ($self,$req) = @_;
+###l4p     get_logger()->debug( "create" );
     ++$self->statistics->{create};
-    return $self->base_strategy->create_cache_record(
-        $name,$normaliser,$coderef,$args,$return_type);
+    return $self->base_strategy->create( $req );
 }
 
-sub get_cache_record
+#
+# get REQ
+#
+sub get
 {
-    my ($self,$name,$normaliser,$coderef,$args,$return_type) = @_;
-###l4p     get_logger()->debug( "get_cache_record" );
-    my $rec = $self->base_strategy->get_cache_record(
-        $name, $normaliser, $coderef, $args, $return_type );    
+    my ($self,$req) = @_;
+###l4p     get_logger()->debug( "get" );
+    my $rec = $self->base_strategy->get(
+        $req );
     if( $rec )
     {
         ++$self->statistics->{hit};
@@ -53,11 +58,29 @@ sub get_cache_record
     return $rec;
 }
 
-sub set_cache_record
+#
+# REQ REC
+#
+sub set
 {
-    my ($self,$rec) = @_;
-###l4p     get_logger()->debug( "set_cache_record " . $rec->name );
-    return $self->base_strategy->set_cache_record( $rec );    
+    my ($self,$req,$rec) = @_;
+###l4p     get_logger()->debug( "set " . $rec->name );
+    return $self->base_strategy->set( $req, $rec );
+}
+
+#
+# delete KEY
+#
+sub delete
+{
+    my ($self,$key) = @_;
+    return $self->base_strategy->delete( $key );
+}
+
+sub clear
+{
+    my ($self) = @_;
+    return $self->base_strategy->clear;
 }
 
 sub _build_base_strategy
@@ -93,7 +116,7 @@ around BUILDARGS => sub
 ###l4p             get_logger()->debug( "base strategy node found" );
             $args{base_strategy} = Autocache->singleton->get_strategy( $node->value );
         }
-        
+
         return $class->$orig( %args );
     }
     else
